==> components-2.0.7.tgz: package/esm/Atoms/Icons/withStyle.js <==
function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _templateObject() {
  var data = _taggedTemplateLiteral(["\n  fill: ", ";\n  cursor: ", ";\n\n  &:hover {\n    fill: ", ";\n  }\n"]);

  _templateObject = function _templateObject() {
    return data;
  };

  return data;
}

function _taggedTemplateLiteral(strings, raw) { if (!raw) { raw = strings.slice(0); } return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

import React from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';
var Wrapper = styled.svg(_templateObject(), function (props) {
  return props.theme['iconColor'];
}, function (props) {
  return props.selectable ? 'pointer' : 'default';
}, function (props) {
  return props.selectable ? props.theme['iconHoverColor'] : props.theme['iconColor'];
});
export default (function (path, width, height, name) {
  /* eslint-disable react/prefer-stateless-function */
  var WithStyle =
  /*#__PURE__*/
  function (_React$PureComponent) {
    _inherits(WithStyle, _React$PureComponent);

    function WithStyle() {
      _classCallCheck(this, WithStyle);

      return _possibleConstructorReturn(this, _getPrototypeOf(WithStyle).apply(this, arguments));
    }

    _createClass(WithStyle, [{
      key: "render",
      value: function render() {
        var _this$props = this.props,
            size = _this$props.size,
            rest = _objectWithoutProperties(_this$props, ["size"]);

        return React.createElement(Wrapper, _extends({
          height: size,
          viewBox: "0 0 ".concat(width, " ").concat(height),
          width: size,
          xmlns: "http://www.w3.org/2000/svg"
        }, rest), path);
      }
    }]);

    return WithStyle;
  }(React.PureComponent);

  WithStyle.displayName = name;
  WithStyle.propTypes = {
    selectable: PropTypes.bool,
    size: PropTypes.string
  };
  WithStyle.defaultProps = {
    selectable: false,
    size: '44px'
  };
  return WithStyle;
});

==> components-2.0.10.tgz: package/esm/Atoms/Icons/withStyle.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import _classCallCheck from "@babel/runtime/helpers/esm/classCallCheck";
import _createClass from "@babel/runtime/helpers/esm/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/esm/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/esm/inherits";
import React from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';
var Wrapper =
/*#__PURE__*/
styled.svg.withConfig({
  componentId: "sc-1pmbxjh-0"
})(["fill:", ";cursor:", ";&:hover{fill:", ";}"], function (props) {
  return props.theme['iconColor'];
}, function (props) {
  return props.selectable ? 'pointer' : 'default';
}, function (props) {
  return props.selectable ? props.theme['iconHoverColor'] : props.theme['iconColor'];
});
export default (function (path, width, height, name) {
  /* eslint-disable react/prefer-stateless-function */
  var WithStyle =
  /*#__PURE__*/
  function (_React$PureComponent) {
    _inherits(WithStyle, _React$PureComponent);

    function WithStyle() {
      _classCallCheck(this, WithStyle);

      return _possibleConstructorReturn(this, _getPrototypeOf(WithStyle).apply(this, arguments));
    }

    _createClass(WithStyle, [{
      key: "render",
      value: function render() {
        var _this$props = this.props,
            size = _this$props.size,
            rest = _objectWithoutProperties(_this$props, ["size"]);

        return React.createElement(Wrapper, _extends({
          height: size,
          viewBox: "0 0 ".concat(width, " ").concat(height),
          width: size,
          xmlns: "http://www.w3.org/2000/svg"
        }, rest), path);
      }
    }]);

    return WithStyle;
  }(React.PureComponent);

  WithStyle.displayName = name;
  WithStyle.propTypes = process.env.NODE_ENV !== "production" ? {
    selectable: PropTypes.bool,
    size: PropTypes.string
  } : {};
  WithStyle.defaultProps = {
    selectable: false,
    size: '44px'
  };
  return WithStyle;
});
